==> core-1.64.1-sources.jar: software/amazon/awscdk/core/AppProps.java <==
package software.amazon.awscdk.core;

/**
 * Initialization props for apps.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.12.0 (build 5ddc9f2)", date = "2020-09-25T17:38:57.403Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.AppProps")
@software.amazon.jsii.Jsii.Proxy(AppProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AppProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Automatically call `synth()` before the program exits.
     * <p>
     * If you set this, you don't have to call <code>synth()</code> explicitly. Note that
     * this feature is only available for certain programming languages, and
     * calling <code>synth()</code> is still recommended.
     * <p>
     * Default: true if running via CDK CLI (`CDK_OUTDIR` is set), `false`
     * otherwise
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAutoSynth() {
        return null;
    }

    /**
     * Additional context values for the application.
     * <p>
     * Context set by the CLI or the <code>context</code> key in <code>cdk.json</code> has precedence.
     * <p>
     * Context can be read from any construct using <code>node.getContext(key)</code>.
     * <p>
     * Default: - no additional context
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Object> getContext() {
        return null;
    }

    /**
     * The output directory into which to emit synthesized artifacts.
     * <p>
     * Default: - If this value is _not_ set, considers the environment variable `CDK_OUTDIR`.
     *   If `CDK_OUTDIR` is not defined, uses a temp directory.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getOutdir() {
        return null;
    }

    /**
     * Include runtime versioning information in cloud assembly manifest.
     * <p>
     * Default: true runtime info is included unless `aws:cdk:disable-runtime-info` is set in the context.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getRuntimeInfo() {
        return null;
    }

    /**
     * Include construct creation stack trace in the `aws:cdk:trace` metadata key of all constructs.
     * <p>
     * Default: true stack traces are included unless `aws:cdk:disable-stack-trace` is set in the context.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getStackTraces() {
        return null;
    }

    /**
     * Include construct tree metadata as part of the Cloud Assembly.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTreeMetadata() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AppProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AppProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AppProps> {
        private java.lang.Boolean autoSynth;
        private java.util.Map<java.lang.String, java.lang.Object> context;
        private java.lang.String outdir;
        private java.lang.Boolean runtimeInfo;
        private java.lang.Boolean stackTraces;
        private java.lang.Boolean treeMetadata;

        /**
         * Sets the value of {@link AppProps#getAutoSynth}
         * @param autoSynth Automatically call `synth()` before the program exits.
         *                  If you set this, you don't have to call <code>synth()</code> explicitly. Note that
         *                  this feature is only available for certain programming languages, and
         *                  calling <code>synth()</code> is still recommended.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder autoSynth(java.lang.Boolean autoSynth) {
            this.autoSynth = autoSynth;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getContext}
         * @param context Additional context values for the application.
         *                Context set by the CLI or the <code>context</code> key in <code>cdk.json</code> has precedence.
         *                <p>
         *                Context can be read from any construct using <code>node.getContext(key)</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder context(java.util.Map<java.lang.String, ? extends java.lang.Object> context) {
            this.context = (java.util.Map<java.lang.String, java.lang.Object>)context;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getOutdir}
         * @param outdir The output directory into which to emit synthesized artifacts.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder outdir(java.lang.String outdir) {
            this.outdir = outdir;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getRuntimeInfo}
         * @param runtimeInfo Include runtime versioning information in cloud assembly manifest.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder runtimeInfo(java.lang.Boolean runtimeInfo) {
            this.runtimeInfo = runtimeInfo;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getStackTraces}
         * @param stackTraces Include construct creation stack trace in the `aws:cdk:trace` metadata key of all constructs.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stackTraces(java.lang.Boolean stackTraces) {
            this.stackTraces = stackTraces;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getTreeMetadata}
         * @param treeMetadata Include construct tree metadata as part of the Cloud Assembly.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder treeMetadata(java.lang.Boolean treeMetadata) {
            this.treeMetadata = treeMetadata;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AppProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AppProps build() {
            return new Jsii$Proxy(autoSynth, context, outdir, runtimeInfo, stackTraces, treeMetadata);
        }
    }

    /**
     * An implementation for {@link AppProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AppProps {
        private final java.lang.Boolean autoSynth;
        private final java.util.Map<java.lang.String, java.lang.Object> context;
        private final java.lang.String outdir;
        private final java.lang.Boolean runtimeInfo;
        private final java.lang.Boolean stackTraces;
        private final java.lang.Boolean treeMetadata;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.autoSynth = this.jsiiGet("autoSynth", java.lang.Boolean.class);
            this.context = this.jsiiGet("context", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.outdir = this.jsiiGet("outdir", java.lang.String.class);
            this.runtimeInfo = this.jsiiGet("runtimeInfo", java.lang.Boolean.class);
            this.stackTraces = this.jsiiGet("stackTraces", java.lang.Boolean.class);
            this.treeMetadata = this.jsiiGet("treeMetadata", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        private Jsii$Proxy(final java.lang.Boolean autoSynth, final java.util.Map<java.lang.String, ? extends java.lang.Object> context, final java.lang.String outdir, final java.lang.Boolean runtimeInfo, final java.lang.Boolean stackTraces, final java.lang.Boolean treeMetadata) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.autoSynth = autoSynth;
            this.context = (java.util.Map<java.lang.String, java.lang.Object>)context;
            this.outdir = outdir;
            this.runtimeInfo = runtimeInfo;
            this.stackTraces = stackTraces;
            this.treeMetadata = treeMetadata;
        }

        @Override
        public java.lang.Boolean getAutoSynth() {
            return this.autoSynth;
        }

        @Override
        public java.util.Map<java.lang.String, java.lang.Object> getContext() {
            return this.context;
        }

        @Override
        public java.lang.String getOutdir() {
            return this.outdir;
        }

        @Override
        public java.lang.Boolean getRuntimeInfo() {
            return this.runtimeInfo;
        }

        @Override
        public java.lang.Boolean getStackTraces() {
            return this.stackTraces;
        }

        @Override
        public java.lang.Boolean getTreeMetadata() {
            return this.treeMetadata;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAutoSynth() != null) {
                data.set("autoSynth", om.valueToTree(this.getAutoSynth()));
            }
            if (this.getContext() != null) {
                data.set("context", om.valueToTree(this.getContext()));
            }
            if (this.getOutdir() != null) {
                data.set("outdir", om.valueToTree(this.getOutdir()));
            }
            if (this.getRuntimeInfo() != null) {
                data.set("runtimeInfo", om.valueToTree(this.getRuntimeInfo()));
            }
            if (this.getStackTraces() != null) {
                data.set("stackTraces", om.valueToTree(this.getStackTraces()));
            }
            if (this.getTreeMetadata() != null) {
                data.set("treeMetadata", om.valueToTree(this.getTreeMetadata()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/core.AppProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AppProps.Jsii$Proxy that = (AppProps.Jsii$Proxy) o;

            if (this.autoSynth != null ? !this.autoSynth.equals(that.autoSynth) : that.autoSynth != null) return false;
            if (this.context != null ? !this.context.equals(that.context) : that.context != null) return false;
            if (this.outdir != null ? !this.outdir.equals(that.outdir) : that.outdir != null) return false;
            if (this.runtimeInfo != null ? !this.runtimeInfo.equals(that.runtimeInfo) : that.runtimeInfo != null) return false;
            if (this.stackTraces != null ? !this.stackTraces.equals(that.stackTraces) : that.stackTraces != null) return false;
            return this.treeMetadata != null ? this.treeMetadata.equals(that.treeMetadata) : that.treeMetadata == null;
        }

        @Override
        public int hashCode() {
            int result = this.autoSynth != null ? this.autoSynth.hashCode() : 0;
            result = 31 * result + (this.context != null ? this.context.hashCode() : 0);
            result = 31 * result + (this.outdir != null ? this.outdir.hashCode() : 0);
            result = 31 * result + (this.runtimeInfo != null ? this.runtimeInfo.hashCode() : 0);
            result = 31 * result + (this.stackTraces != null ? this.stackTraces.hashCode() : 0);
            result = 31 * result + (this.treeMetadata != null ? this.treeMetadata.hashCode() : 0);
            return result;
        }
    }
}

==> core-1.65.0-sources.jar: software/amazon/awscdk/core/AppProps.java <==
package software.amazon.awscdk.core;

/**
 * Initialization props for apps.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.12.0 (build 5ddc9f2)", date = "2020-10-01T01:49:28.980Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.AppProps")
@software.amazon.jsii.Jsii.Proxy(AppProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AppProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Include runtime versioning information in the Stacks of this app.
     * <p>
     * Default: Value of 'aws:cdk:version-reporting' context key
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAnalyticsReporting() {
        return null;
    }

    /**
     * Automatically call `synth()` before the program exits.
     * <p>
     * If you set this, you don't have to call <code>synth()</code> explicitly. Note that
     * this feature is only available for certain programming languages, and
     * calling <code>synth()</code> is still recommended.
     * <p>
     * Default: true if running via CDK CLI (`CDK_OUTDIR` is set), `false`
     * otherwise
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAutoSynth() {
        return null;
    }

    /**
     * Additional context values for the application.
     * <p>
     * Context set by the CLI or the <code>context</code> key in <code>cdk.json</code> has precedence.
     * <p>
     * Context can be read from any construct using <code>node.getContext(key)</code>.
     * <p>
     * Default: - no additional context
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Object> getContext() {
        return null;
    }

    /**
     * The output directory into which to emit synthesized artifacts.
     * <p>
     * Default: - If this value is _not_ set, considers the environment variable `CDK_OUTDIR`.
     *   If `CDK_OUTDIR` is not defined, uses a temp directory.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getOutdir() {
        return null;
    }

    /**
     * Include runtime versioning information in the Stacks of this app.
     * <p>
     * Default: Value of 'aws:cdk:version-reporting' context key
     * <p>
     * @deprecated use `versionReporting` instead
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getRuntimeInfo() {
        return null;
    }

    /**
     * Include construct creation stack trace in the `aws:cdk:trace` metadata key of all constructs.
     * <p>
     * Default: true stack traces are included unless `aws:cdk:disable-stack-trace` is set in the context.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getStackTraces() {
        return null;
    }

    /**
     * Include construct tree metadata as part of the Cloud Assembly.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTreeMetadata() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AppProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AppProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AppProps> {
        private java.lang.Boolean analyticsReporting;
        private java.lang.Boolean autoSynth;
        private java.util.Map<java.lang.String, java.lang.Object> context;
        private java.lang.String outdir;
        private java.lang.Boolean runtimeInfo;
        private java.lang.Boolean stackTraces;
        private java.lang.Boolean treeMetadata;

        /**
         * Sets the value of {@link AppProps#getAnalyticsReporting}
         * @param analyticsReporting Include runtime versioning information in the Stacks of this app.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder analyticsReporting(java.lang.Boolean analyticsReporting) {
            this.analyticsReporting = analyticsReporting;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getAutoSynth}
         * @param autoSynth Automatically call `synth()` before the program exits.
         *                  If you set this, you don't have to call <code>synth()</code> explicitly. Note that
         *                  this feature is only available for certain programming languages, and
         *                  calling <code>synth()</code> is still recommended.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder autoSynth(java.lang.Boolean autoSynth) {
            this.autoSynth = autoSynth;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getContext}
         * @param context Additional context values for the application.
         *                Context set by the CLI or the <code>context</code> key in <code>cdk.json</code> has precedence.
         *                <p>
         *                Context can be read from any construct using <code>node.getContext(key)</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder context(java.util.Map<java.lang.String, ? extends java.lang.Object> context) {
            this.context = (java.util.Map<java.lang.String, java.lang.Object>)context;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getOutdir}
         * @param outdir The output directory into which to emit synthesized artifacts.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder outdir(java.lang.String outdir) {
            this.outdir = outdir;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getRuntimeInfo}
         * @param runtimeInfo Include runtime versioning information in the Stacks of this app.
         * @return {@code this}
         * @deprecated use `versionReporting` instead
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder runtimeInfo(java.lang.Boolean runtimeInfo) {
            this.runtimeInfo = runtimeInfo;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getStackTraces}
         * @param stackTraces Include construct creation stack trace in the `aws:cdk:trace` metadata key of all constructs.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stackTraces(java.lang.Boolean stackTraces) {
            this.stackTraces = stackTraces;
            return this;
        }

        /**
         * Sets the value of {@link AppProps#getTreeMetadata}
         * @param treeMetadata Include construct tree metadata as part of the Cloud Assembly.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder treeMetadata(java.lang.Boolean treeMetadata) {
            this.treeMetadata = treeMetadata;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AppProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AppProps build() {
            return new Jsii$Proxy(analyticsReporting, autoSynth, context, outdir, runtimeInfo, stackTraces, treeMetadata);
        }
    }

    /**
     * An implementation for {@link AppProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AppProps {
        private final java.lang.Boolean analyticsReporting;
        private final java.lang.Boolean autoSynth;
        private final java.util.Map<java.lang.String, java.lang.Object> context;
        private final java.lang.String outdir;
        private final java.lang.Boolean runtimeInfo;
        private final java.lang.Boolean stackTraces;
        private final java.lang.Boolean treeMetadata;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.analyticsReporting = this.jsiiGet("analyticsReporting", java.lang.Boolean.class);
            this.autoSynth = this.jsiiGet("autoSynth", java.lang.Boolean.class);
            this.context = this.jsiiGet("context", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.outdir = this.jsiiGet("outdir", java.lang.String.class);
            this.runtimeInfo = this.jsiiGet("runtimeInfo", java.lang.Boolean.class);
            this.stackTraces = this.jsiiGet("stackTraces", java.lang.Boolean.class);
            this.treeMetadata = this.jsiiGet("treeMetadata", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        private Jsii$Proxy(final java.lang.Boolean analyticsReporting, final java.lang.Boolean autoSynth, final java.util.Map<java.lang.String, ? extends java.lang.Object> context, final java.lang.String outdir, final java.lang.Boolean runtimeInfo, final java.lang.Boolean stackTraces, final java.lang.Boolean treeMetadata) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.analyticsReporting = analyticsReporting;
            this.autoSynth = autoSynth;
            this.context = (java.util.Map<java.lang.String, java.lang.Object>)context;
            this.outdir = outdir;
            this.runtimeInfo = runtimeInfo;
            this.stackTraces = stackTraces;
            this.treeMetadata = treeMetadata;
        }

        @Override
        public java.lang.Boolean getAnalyticsReporting() {
            return this.analyticsReporting;
        }

        @Override
        public java.lang.Boolean getAutoSynth() {
            return this.autoSynth;
        }

        @Override
        public java.util.Map<java.lang.String, java.lang.Object> getContext() {
            return this.context;
        }

        @Override
        public java.lang.String getOutdir() {
            return this.outdir;
        }

        @Override
        public java.lang.Boolean getRuntimeInfo() {
            return this.runtimeInfo;
        }

        @Override
        public java.lang.Boolean getStackTraces() {
            return this.stackTraces;
        }

        @Override
        public java.lang.Boolean getTreeMetadata() {
            return this.treeMetadata;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAnalyticsReporting() != null) {
                data.set("analyticsReporting", om.valueToTree(this.getAnalyticsReporting()));
            }
            if (this.getAutoSynth() != null) {
                data.set("autoSynth", om.valueToTree(this.getAutoSynth()));
            }
            if (this.getContext() != null) {
                data.set("context", om.valueToTree(this.getContext()));
            }
            if (this.getOutdir() != null) {
                data.set("outdir", om.valueToTree(this.getOutdir()));
            }
            if (this.getRuntimeInfo() != null) {
                data.set("runtimeInfo", om.valueToTree(this.getRuntimeInfo()));
            }
            if (this.getStackTraces() != null) {
                data.set("stackTraces", om.valueToTree(this.getStackTraces()));
            }
            if (this.getTreeMetadata() != null) {
                data.set("treeMetadata", om.valueToTree(this.getTreeMetadata()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/core.AppProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AppProps.Jsii$Proxy that = (AppProps.Jsii$Proxy) o;

            if (this.analyticsReporting != null ? !this.analyticsReporting.equals(that.analyticsReporting) : that.analyticsReporting != null) return false;
            if (this.autoSynth != null ? !this.autoSynth.equals(that.autoSynth) : that.autoSynth != null) return false;
            if (this.context != null ? !this.context.equals(that.context) : that.context != null) return false;
            if (this.outdir != null ? !this.outdir.equals(that.outdir) : that.outdir != null) return false;
            if (this.runtimeInfo != null ? !this.runtimeInfo.equals(that.runtimeInfo) : that.runtimeInfo != null) return false;
            if (this.stackTraces != null ? !this.stackTraces.equals(that.stackTraces) : that.stackTraces != null) return false;
            return this.treeMetadata != null ? this.treeMetadata.equals(that.treeMetadata) : that.treeMetadata == null;
        }

        @Override
        public int hashCode() {
            int result = this.analyticsReporting != null ? this.analyticsReporting.hashCode() : 0;
            result = 31 * result + (this.autoSynth != null ? this.autoSynth.hashCode() : 0);
            result = 31 * result + (this.context != null ? this.context.hashCode() : 0);
            result = 31 * result + (this.outdir != null ? this.outdir.hashCode() : 0);
            result = 31 * result + (this.runtimeInfo != null ? this.runtimeInfo.hashCode() : 0);
            result = 31 * result + (this.stackTraces != null ? this.stackTraces.hashCode() : 0);
            result = 31 * result + (this.treeMetadata != null ? this.treeMetadata.hashCode() : 0);
            return result;
        }
    }
}
